@@ -107,7 +107,7 @@ extract_params = function(params_sleep = c(), params_metrics = c(),
             "config_file_in_outputdir", "imputeTimegaps",
             "argNames", "dupArgNames","do.sgAccEN", "do.sgAnglex", 
             "do.sgAngley", "do.sgAnglez", "frag.classes.spt", "i", 
-            "isna", "tmp", "vecchar", "dupi")
+            "isna", "tmp", "vecchar", "dupi", "GGIRread_version")
           # Find argument in the various parameter objects
           if (newValue[1] != "notfound" & varName %in% ArgNames2Ignore == FALSE) {
             if (varName %in% names(params_general)) {
