@@ -83,7 +83,8 @@ g.plot5 = function(metadatadir=c(),dofirstpage=FALSE, viewingwindow = 1,f0=c(),f
           if (length(della) > 0) summarysleep_tmp = summarysleep_tmp[-della,]
         }
         # do not include days with no meaningful data
-        d2excludeb = d2exclude = which(daysummary_tmp$N.valid.hours < 10)
+        threshold_hrs_of_data_per_day = 0.5
+        d2excludeb = d2exclude = which(daysummary_tmp$N.valid.hours < threshold_hrs_of_data_per_day)
         n2excludeb = n2exclude = which(summarysleep_tmp$fraction_night_invalid > 0.66
                                        | summarysleep_tmp$SptDuration == 0)
         if (length(d2exclude) > 0) {
@@ -345,14 +346,18 @@ g.plot5 = function(metadatadir=c(),dofirstpage=FALSE, viewingwindow = 1,f0=c(),f
             if (g == 1) {
               t0 = 1
               t1 = nightsi[g]-1
-              if ((t1 - t0) < (6*(60/ws3)*60)) skip = TRUE
+              if ((t1 - t0) < (threshold_hrs_of_data_per_day*(60/ws3)*60)) {
+                skip = TRUE
+              }
             } else if (g > 1 & g < nplots) {
               t0 = nightsi[g-1]
               t1 = nightsi[g]-1
             }  else if (g == nplots) {
               t0 = nightsi[g-1]
               t1 = length(time)
-              if ((t1 - t0) < (6*(60/ws3)*60)) skip = TRUE
+              if ((t1 - t0) < (threshold_hrs_of_data_per_day*(60/ws3)*60)) {
+                skip = TRUE
+              }
             }
             if (((t1-t0) + 1) / (60*60/ws3) == 25) { # day with 25 hours, just pretend that 25th hour did not happen
               t1 = t1 - (60*60/ws3)
@@ -583,10 +588,10 @@ g.plot5 = function(metadatadir=c(),dofirstpage=FALSE, viewingwindow = 1,f0=c(),f
             curr_date_unclassed = unclass(as.POSIXlt(curr_date,desiredtz))
             title = paste("Day ",daycount,": ",
                           wdaynames[curr_date_unclassed$wday+1],
-                          " ",
-                          curr_date_unclassed$mday,"/",
-                          curr_date_unclassed$mon+1,"/",
-                          curr_date_unclassed$year+1900,sep="")
+                          " | ",
+                          curr_date_unclassed$mday, " ",
+                          month.abb[curr_date_unclassed$mon+1], " ",
+                          curr_date_unclassed$year+1900, sep="")
             rm(curr_date_unclassed)
             if (skip == FALSE) {
               YXLIM = c(-230,300)
@@ -598,7 +603,7 @@ g.plot5 = function(metadatadir=c(),dofirstpage=FALSE, viewingwindow = 1,f0=c(),f
                 # plot z-angle:
                 lines(x,ang, type="l",lwd=LWDA,bty="l",xlab="",ylab="",cex=0.3,lend=LJ)
               } else {
-                print('plot5 error: index, acc and ang vectors are different lengths')
+                warning('\nplot5 error: index, acc and ang vectors are different lengths')
               }
               # add sleeponset time annotation to plot:
               arrow_line_length = length(x) * 0.01736 # make arrow line length adaptable to differnt short epochs
