@@ -3,15 +3,6 @@ context("Chainof5parts")
 test_that("chainof5parts", {
   skip_on_cran()
 
-  
-  # dirR = "~/GGIR/R"
-  # ffnames = dir(dirR) # creating list of filenames of scriptfiles to load
-  # ffnames = ffnames[which(ffnames %in% c("g.cwaread.R", "read.gt3x_ggir.R") == FALSE)]
-  # for (i in 1:length(ffnames)) {
-  #   source(paste(dirR,"/",ffnames[i],sep="")) #loading scripts for reading geneactiv data
-  # }
-  # library(testthat)
-  
   Ndays = 2
   create_test_acc_csv(Nmin = Ndays*1440)
   create_test_sleeplog_csv(advanced = FALSE)
@@ -33,15 +24,15 @@ test_that("chainof5parts", {
   expect_true(dir.exists(dn))
   rn = dir("output_test/meta/basic/",full.names = TRUE)
   load(rn[1])
-  expect_that(round(C$scale, digits = 5), equals(c(0.98474, 0.98393, 0.98439)))
-  expect_that(nrow(M$metalong),equals(47))
+  expect_equal(round(C$scale, digits = 5), c(0.98473, 0.98425, 0.98462), tolerance = 3)
+  expect_that(nrow(M$metalong), equals(47))
   # expect_that(M$metalong[2,1],equals("2016-06-23T09:15:00+0100")) # turned off because not consistent across machines, to investigate
   expect_that(nrow(M$metashort),equals(11280))
-  expect_that(round(mean(M$metashort$ENMO), digits = 5), equals(0.02896))
+  expect_equal(round(mean(M$metashort$ENMO), digits = 5), 0.02911, tolerance = 3)
   expect_that(I$monc, equals(3))
   expect_that(I$sf, equals(3))
   expect_that(I$dformc, equals(2))
-  expect_that(C$npoints, equals(9768))
+  expect_equal(C$npoints, 7494, tolerance = 5)
   #-------------------------
   # part 2 with strategy = 3
   g.part2(datadir = fn, metadatadir = metadatadir, f0 = 1, f1 = 1,
@@ -51,9 +42,9 @@ test_that("chainof5parts", {
   dirname = "output_test/meta/ms2.out/"
   rn = dir(dirname,full.names = TRUE)
   load(rn[1])
-  expect_that(nrow(IMP$metashort),equals(11280))
-  expect_that(round(mean(IMP$metashort$ENMO), digits = 5), equals(0.00796))
-  expect_that(round(as.numeric(SUM$summary$meas_dur_def_proto_day), digits = 3), equals(0.417))
+  expect_equal(nrow(IMP$metashort), 11280)
+  expect_equal(round(mean(IMP$metashort$ENMO), digits = 5), 0.00802, tolerance = 3)
+  expect_equal(round(as.numeric(SUM$summary$meas_dur_def_proto_day), digits = 3), 0.417)
   # part 2 with strategy = 2 and iglevels = 1
   g.part2(datadir = fn, metadatadir = metadatadir, f0 = 1, f1 = 1,
           idloc = 2, desiredtz = desiredtz,
@@ -64,9 +55,9 @@ test_that("chainof5parts", {
   rn = dir(dirname,full.names = TRUE)
   load(rn[1])
   expect_that(nrow(IMP$metashort),equals(11280))
-  expect_that(round(mean(IMP$metashort$ENMO),digits = 3), equals(0.029))
-  expect_that(round(as.numeric(SUM$summary$meas_dur_def_proto_day), digits = 2), equals(1))
-  expect_equal(round(as.numeric(SUM$daysummary$`L16_ig_gradient_ENMO_mg_0-24hr`[1]), digits = 2), -1.11)
+  expect_equal(mean(IMP$metashort$ENMO), 0.029, tolerance = 3)
+  expect_equal(as.numeric(SUM$summary$meas_dur_def_proto_day), 1, tolerance = 2)
+  expect_equal(as.numeric(SUM$daysummary$`L16_ig_gradient_ENMO_mg_0-24hr`[1]), -1.12, tolerance = 2)
   # part 2 with strategy = 1
   g.part2(datadir = fn, metadatadir = metadatadir, f0 = 1, f1 = 1,
           idloc = 2, desiredtz = desiredtz,
@@ -83,11 +74,11 @@ test_that("chainof5parts", {
   expect_true(file.exists(summarycsv))
   expect_true(file.exists(daysummarycsv))
   expect_that(nrow(IMP$metashort), equals(11280))
-  expect_that(round(mean(IMP$metashort$ENMO), digits = 5), equals(0.02896))
+  expect_equal(round(mean(IMP$metashort$ENMO), digits = 5), 0.02911, tolerance = 3)
   expect_that(round(as.numeric(SUM$summary$meas_dur_dys), digits = 5), equals(1.95833))
   expect_that(ncol(SUM$daysummary), equals(32))
-  expect_that(round(mean(as.numeric(SUM$daysummary$`M3_ENMO_mg_0-24hr`)), digits = 3),equals(88.946))
-  expect_that(round(mean(as.numeric(SUM$daysummary$`M3_q40_ENMO_mg_0-24hr`)), digits = 3), equals(37.067))
+  expect_equal(mean(as.numeric(SUM$daysummary$`M3_ENMO_mg_0-24hr`)), 89.26, tolerance = 3)
+  expect_equal(mean(as.numeric(SUM$daysummary$`M3_q40_ENMO_mg_0-24hr`)), 37.383, tolerance = 3)
 
   #--------------------------------------------
   # part 3
@@ -134,15 +125,15 @@ test_that("chainof5parts", {
   expect_true(dir.exists(dirname))
   expect_true(file.exists(rn[1]))
   expect_that(nrow(output),equals(3)) # changed because part5 now gives also first and last day
-  expect_that(ncol(output),equals(149))
+  expect_that(ncol(output),equals(152))
   expect_that(round(as.numeric(output$wakeup[2]), digits = 4), equals(35.9958))
   dirname_raw = "output_test/meta/ms5.outraw/40_100_400"
   rn2 = dir(dirname_raw,full.names = TRUE, recursive = T)
   expect_true(file.exists(rn2[1]))
   TSFILE = read.csv(rn2[1])
   expect_that(nrow(TSFILE),equals(4601))
-  expect_that(ncol(TSFILE),equals(10))
-  expect_that(length(unique(TSFILE$class_id)),equals(10))
+  expect_equal(ncol(TSFILE), 10)
+  expect_equal(length(unique(TSFILE$class_id)), 10)
  #--------------------------------------------
   #GGIR
   suppressWarnings(GGIR(mode = c(2,3,4,5), datadir = fn, outputdir = getwd(),
@@ -159,26 +150,7 @@ test_that("chainof5parts", {
   expect_true(file.exists("output_test/results/part4_summary_sleep_cleaned.csv"))
   expect_true(file.exists("output_test/results/file summary reports/Report_123A_testaccfile.csv.pdf"))
   dn = "output_test"
-  #--------------------------------------------
-  # create dummy selectdaysfile
-  selectdays = data.frame(Monitor = "MOS2D12345678",
-                          Day1 = "24/06/2016",
-                          Day2 = "25/06/2016", stringsAsFactors = TRUE)
-  selectdaysfile = paste0(getwd(), "/selectdaysfile.csv")
-  write.csv(selectdays, file = selectdaysfile, row.names = FALSE, fileEncoding = "UTF-8")
-  # we will now use it in g.part2, not sure whether g.part2 will actually be able to handle this.
-  # normally, g.part1 would use the file to cut up the measurement, but that only works for GENEActiv
-  # data and we do not have a multi-data GENEActiv test file in the package.
-  g.part2(datadir = fn, metadatadir = metadatadir, f0 = 1, f1 = 1,
-          idloc = 2, desiredtz = desiredtz, strategy = 1,
-          overwrite = TRUE, hrs.del.start = 0, hrs.del.end = 0,
-          maxdur = Ndays, includedaycrit = 0, selectdaysfile = selectdaysfile,
-          storefolderstructure = TRUE, do.parallel = do.parallel, myfun = c())
-  rn = dir(dirname, full.names = TRUE)
-  load(rn[1])
-  expect_that(nrow(IMP$metashort), equals(11280))
-  expect_that(round(mean(IMP$metashort$ENMO), digits = 5), equals(0.02896))
-
+  
   #=======================
   # Different variations on part 4:
   #--------------------------------------------
@@ -323,20 +295,14 @@ test_that("chainof5parts", {
   rn = dir("output_test/meta/basic/", full.names = TRUE)
   load(rn[1])
   expect_equal(ncol(M$metashort), 24)
-  expect_equal(round(mean(M$metashort$B, na.rm = T), digits = 3), 24.718)
-  expect_equal(round(mean(M$metashort$C, na.rm = T), digits = 3), -6.528)
-  expect_equal(round(mean(M$metashort$EN, na.rm = T), digits = 3), 1.029)
-  expect_equal(round(mean(M$metashort$angley, na.rm = T), digits = 3), 0.768)
-  expect_equal(round(mean(M$metashort$roll_med_acc_x, na.rm = T), digits = 3), 0.728)
-  expect_equal(round(mean(M$metashort$roll_med_acc_z, na.rm = T), digits = 3), 0.007)
-  expect_equal(round(mean(M$metashort$dev_roll_med_acc_x, na.rm = T), digits = 3), 0.007)
-  expect_equal(round(mean(M$metashort$ENMOa, na.rm = T),digits = 3), 0.03)
-
-  SDF = "output_test/meta/raw/123A_testaccfile.csv_day1.RData"
-  expect_true(file.exists(SDF))
-  load(SDF)
-  expect_that(nrow(data),equals(390600))
-  expect_that(round(mean(data),digits = 3), equals(0.266))
+  expect_equal(mean(M$metashort$B, na.rm = T), 24.673, tolerance = 3)
+  expect_equal(mean(M$metashort$C, na.rm = T), -6.642, tolerance = 3)
+  expect_equal(mean(M$metashort$EN, na.rm = T), 1.029, tolerance = 3)
+  expect_equal(mean(M$metashort$angley, na.rm = T), 0.765, tolerance = 3)
+  expect_equal(mean(M$metashort$roll_med_acc_x, na.rm = T), 0.729, tolerance = 3)
+  expect_equal(mean(M$metashort$roll_med_acc_z, na.rm = T), 0.007, tolerance = 3)
+  expect_equal(mean(M$metashort$dev_roll_med_acc_x, na.rm = T), 0.007, tolerance = 3)
+  expect_equal(mean(M$metashort$ENMOa, na.rm = T), 0.03, tolerance = 3)
 
 
   if (file.exists(selectdaysfile)) file.remove(selectdaysfile)
